@@ -59,7 +59,7 @@ class RandomCommentMiddleware(object):
     def process_response(self, request, response):
         str_types = string_types + (binary_type,)
         if not getattr(response, 'streaming', False) \
-                and response['Content-Type'].startswith('text/html') \
+                and response.get('Content-Type', '').startswith('text/html') \
                 and isinstance(response.content, str_types) \
                 and not getattr(response, '_random_comment_exempt', False):
             comment = '<!-- {0} -->'.format(
